@@ -16,9 +16,7 @@ def usage():
 
 def generate_expected_output(input_file, unicodes, profile_flags, output_path):
 	args = ["fonttools", "subset", input_file]
-	args.extend(["--notdef-outline",
-		     "--layout-features=*",
-		     "--drop-tables+=DSIG",
+	args.extend(["--drop-tables+=DSIG",
 		     "--drop-tables-=sbix",
 		     "--unicodes=%s" % unicodes,
 		     "--output-file=%s" % output_path])
